@@ -6,6 +6,8 @@ import org.gcube.portlets.user.gisviewer.client.Constants;
 import org.gcube.portlets.user.gisviewer.client.GisViewer;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.Property;
+import org.gcube.portlets.user.gisviewer.client.commons.utils.MapServerRecognize;
+import org.gcube.portlets.user.gisviewer.client.commons.utils.MapServerRecognize.SERVERTYPE;
 import org.gcube.portlets.user.gisviewer.client.resources.Images;
 
 import com.extjs.gxt.ui.client.event.BaseEvent;
@@ -111,9 +113,17 @@ public class LayerToolsPanel extends VerticalPanel {
 		this.layerItem = layerItem;
 		this.layersPanelHandler = layersPanelHandler;
 		
-//		this.btnTransect.setVisible(false);
-		setTransectInfo();
+		this.setStyleAttribute("margin-bottom", "2px");
 		
+//		this.btnTransect.setVisible(false);
+//		setTransectInfo();
+		
+		activeCQLIfAvailable();
+		
+		boolean showTransect = true;
+		
+		updatePropertyInfo(showTransect);
+
 		this.setTableWidth("100%");
 		
 		// layer info
@@ -125,7 +135,7 @@ public class LayerToolsPanel extends VerticalPanel {
 		createOpenButton();
 		createTipImages();
 		createOpacitySlider();
-		createTools();
+		createTools(layerItem.isCqlFilterAvailable(), showTransect);
 		createCloseLayerButton();
 		
 		cp.add(new Html("&nbsp;"));
@@ -142,6 +152,23 @@ public class LayerToolsPanel extends VerticalPanel {
 		this.add(cp);
 	}
 	
+	/**
+	 * 
+	 */
+	private void activeCQLIfAvailable() {
+		
+		SERVERTYPE mapServerType = MapServerRecognize.recongnize(layerItem.getGeoserverUrl());
+		
+		if(mapServerType!=null){
+			
+			if(mapServerType.equals(MapServerRecognize.SERVERTYPE.MAPSERVER)){
+				layerItem.setCqlFilterAvailable(false);
+			}else 
+				layerItem.setCqlFilterAvailable(true);
+		}
+		
+	}
+
 	private void activeTransect(){
 		
 		if ((tableTransect!=null && fieldTransect!=null)) {
@@ -163,7 +190,7 @@ public class LayerToolsPanel extends VerticalPanel {
 		
 	}
 
-	private void createTools() {
+	private void createTools(boolean showCQLFilter, boolean showTransect) {
 		tools = new VerticalPanel();
 		tools.setStyleAttribute("padding-left", TOOLS_PADDING);
 		//tools.setStyleAttribute("background-color", "#E5E5E5");
@@ -176,34 +203,22 @@ public class LayerToolsPanel extends VerticalPanel {
 		toolBar1.add(new SeparatorToolItem());
 //		this.toolBar1.add(btnTransect);
 
-		activeTransect();
+		if(showTransect)
+			activeTransect();
 		
-		
-//		if ((tableTransect!=null && fieldTransect!=null)) {
-//			// transect button
-//			Button btnTransect = new Button("", Images.iconTransect(), new SelectionListener<ButtonEvent>(){
-//				@Override
-//				public void componentSelected(ButtonEvent ce) {
-//					setTransectTip(true);
-//					layersPanelHandler.activateTransect(layerItem, tableTransect, fieldTransect);
-//				}
-//			});
-//			btnTransect.setToolTip("Generate a Transect function");
-//			//btnTransect.setEnabled((tableTransect!=null && fieldTransect!=null));
-//			toolBar1.add(btnTransect);
-//		}
-
-		// filter button
-		Button btnFilter = new Button("", Images.iconFilter(), new SelectionListener<ButtonEvent>(){
-			@Override
-			public void componentSelected(ButtonEvent ce) {
-				int left = ce.getButton().getAbsoluteLeft();
-				int top = ce.getButton().getAbsoluteTop();
-				layersPanelHandler.showFilterQuery(layerItem, left, top);
-			}
-		});
-		btnFilter.setToolTip("Set a CQL filter to the layer " + this.layerItem.getName() + " (or remove previous filter)");
-		toolBar1.add(btnFilter);
+		if(showCQLFilter){
+			// filter button
+			Button btnFilter = new Button("", Images.iconFilter(), new SelectionListener<ButtonEvent>(){
+				@Override
+				public void componentSelected(ButtonEvent ce) {
+					int left = ce.getButton().getAbsoluteLeft();
+					int top = ce.getButton().getAbsoluteTop();
+					layersPanelHandler.showFilterQuery(layerItem, left, top);
+				}
+			});
+			btnFilter.setToolTip("Set a CQL filter to the layer " + this.layerItem.getName() + " (or remove previous filter)");
+			toolBar1.add(btnFilter);
+		}
 
 		// layer export	    
 		Button btnExportLayer = new Button("", Images.iconExport());
@@ -482,7 +497,7 @@ public class LayerToolsPanel extends VerticalPanel {
 	}
 	
 	// sets transect info of a layer into node
-	private void setTransectInfo() {
+	private void setTransectInfoIfAvailable() {
 		if (!layerItem.isHasLegend())
 			return;
 
@@ -502,71 +517,54 @@ public class LayerToolsPanel extends VerticalPanel {
 			}
 		}
 		
-
+		List<Property> result = layerItem.getProperties();
+		
+		System.out.println("property "+layerItem.getProperties());
+		if(result!=null && result.size()>0){
+			
+			boolean cointainsPropertyTransect = false;
+			
+			if (layerItem.containsProperty("maxspeciescountinacell")) {
+				fieldTransect = "maxspeciescountinacell";
+				tableTransect = validateTableName(":", layerItem.getName());
+				cointainsPropertyTransect = true;
+			} else if (layerItem.containsProperty("probability")) {
+				
+//				System.out.println("layerItem.containsProperty ");
+				fieldTransect = "probability";
+				tableTransect = validateTableName(":", layerItem.getName());
+				cointainsPropertyTransect = true;
+			}
+			
+			GWT.log("layerItem: "+layerItem.getName() + " has properties "+layerItem.getProperties()+" contains property transect: "+cointainsPropertyTransect);
+			
+			if(cointainsPropertyTransect)
+				activeTransect();
+		}	
+	}
+	
+	private void updatePropertyInfo(final boolean activeTransectIfAvailable){
+		
 		GisViewer.service.getListProperty(layerItem.getGeoserverUrl(), layerItem, new AsyncCallback<List<Property>>() {
 
 			@Override
 			public void onFailure(Throwable caught) {
 				GWT.log("error on get list property", caught);
-				
+				GWT.log("updatePropertyInfo FAIL!");
 			}
 
 			@Override
 			public void onSuccess(List<Property> result) {
 				layerItem.setProperties(result);
-
-//				System.out.println("property "+layerItem.getProperties());
-				if(result!=null && result.size()>0){
-					
-					boolean cointainsPropertyTransect = false;
-					
-					if (layerItem.containsProperty("maxspeciescountinacell")) {
-						fieldTransect = "maxspeciescountinacell";
-						tableTransect = validateTableName(":", layerItem.getName());
-						cointainsPropertyTransect = true;
-					} else if (layerItem.containsProperty("probability")) {
-						
-//						System.out.println("layerItem.containsProperty ");
-						fieldTransect = "probability";
-						tableTransect = validateTableName(":", layerItem.getName());
-						cointainsPropertyTransect = true;
-					}
-					
-					GWT.log("layerItem: "+layerItem.getName() + " has properties "+layerItem.getProperties()+" contains property transect: "+cointainsPropertyTransect);
-					
-					if(cointainsPropertyTransect)
-						activeTransect();
-				}
-				
-				
 				
+				if(activeTransectIfAvailable)
+					setTransectInfoIfAvailable();
 			}
 		});
-
-		
-		//COMMENTED BY FRANCESCO M.
-//		// search for transect by datastore
-//		if (!foundDefaultStyle) {
-//			boolean foundDataStore = false;
-//			for (int i = 0; (i < Constants.dataStoresWithTransect.length && !foundDataStore); i++) {
-//				if (layerItem.getDataStore().equals(
-//						Constants.dataStoresWithTransect[i]))
-//					foundDataStore = true;
-//			}
-//
-//			if (foundDataStore) {
-//				if (layerItem.containsProperty("maxspeciescountinacell")) {
-//					this.fieldTransect = "maxspeciescountinacell";
-//					this.tableTransect = layerItem.getName();
-//				} else if (layerItem.containsProperty("probability")) {
-//					this.fieldTransect = "probability";
-//					this.tableTransect = layerItem.getName();
-//				}
-//			}
-//		}
-		// TODO: search for a float property 	// layerItem.getFirstFloatPropertyName()
 	}
 	
+	
+
 	/**
 	 * Remove namespace from layer name.
 	 * Used for transect
